---
title: pymdownx.tabbed
---


[Reference](https://facelessuser.github.io/pymdown-extensions/extensions/tabbed/){: class="reference" }

~~~ md
=== "`pip`"

        :::bash
        pip install mkdocs-shadcn


=== "uv"

        :::bash
        uv add mkdocs-shadcn

=== "poetry"

        :::bash
        poetry add mkdocs-shadcn

~~~

=== "`pip`"

        :::bash
        pip install mkdocs-shadcn


=== "uv"

        :::bash
        uv add mkdocs-shadcn

=== "poetry"

        :::bash
        poetry add mkdocs-shadcn